# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qcalibrate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='qcalibrate.proto',
  package='qcalibrateremote.grpc',
  syntax='proto3',
  serialized_options=b'\n\020eu.qruise.qserveB\017QCalibrateProtoP\001\242\002\002QC',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10qcalibrate.proto\x12\x15qcalibrateremote.grpc\"^\n\x14\x41\x64\x64\x45xperimentRequest\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x15\n\rconfiguration\x18\x05 \x01(\t\",\n\x13\x41\x64\x64\x45xperimentResult\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"7\n\nInitialize\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x15\n\rexperiment_id\x18\x02 \x01(\t\"\xab\x02\n\x0bInitialized\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12\x0b\n\x03typ\x18\x03 \x01(\t\x12\x13\n\x0bmodule_name\x18\x04 \x01(\t\x12\x12\n\nclass_name\x18\x05 \x01(\t\x12\x32\n\targuments\x18\x06 \x03(\x0b\x32\x1f.qcalibrateremote.grpc.Argument\x12\x15\n\rconfiguration\x18\x07 \x01(\t\x12=\n\x0fparameter_metas\x18\n \x03(\x0b\x32$.qcalibrateremote.grpc.ParameterMeta\x12\x35\n\x0bpulse_metas\x18\x0b \x03(\x0b\x32 .qcalibrateremote.grpc.PulseMeta\"?\n\tPulseMeta\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rconfiguration\x18\x03 \x01(\t\"C\n\rParameterMeta\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rconfiguration\x18\x03 \x01(\t\"f\n\x08\x41rgument\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x05int64\x18\n \x01(\x03H\x00\x12\x10\n\x06\x64ouble\x18\x0b \x01(\x01H\x00\x12\x10\n\x06string\x18\x0c \x01(\tH\x00\x12\x0e\n\x04\x62ool\x18\r \x01(\x08H\x00\x42\x07\n\x05value\"\x07\n\x05Start\"!\n\x03\x45nd\x12\x0b\n\x03typ\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\".\n\x05Pulse\x12\x11\n\x05times\x18\x01 \x03(\x01\x42\x02\x10\x01\x12\x12\n\x06values\x18\x02 \x03(\x01\x42\x02\x10\x01\"a\n\nParameters\x12\x11\n\titeration\x18\x01 \x01(\x05\x12\x12\n\x06values\x18\x02 \x03(\x01\x42\x02\x10\x01\x12,\n\x06pulses\x18\x03 \x03(\x0b\x32\x1c.qcalibrateremote.grpc.Pulse\"?\n\x03\x46om\x12\x11\n\titeration\x18\x01 \x01(\x05\x12\x17\n\x0f\x66igure_of_merit\x18\x02 \x01(\x01\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"\xd2\x01\n\x07Request\x12\x37\n\ninitialize\x18\x01 \x01(\x0b\x32!.qcalibrateremote.grpc.InitializeH\x00\x12-\n\x05start\x18\x02 \x01(\x0b\x32\x1c.qcalibrateremote.grpc.StartH\x00\x12)\n\x03\x66om\x18\x03 \x01(\x0b\x32\x1a.qcalibrateremote.grpc.FomH\x00\x12)\n\x03\x65nd\x18\n \x01(\x0b\x32\x1a.qcalibrateremote.grpc.EndH\x00\x42\t\n\x07message\"\xb4\x01\n\x08Response\x12\x39\n\x0binitialized\x18\x01 \x01(\x0b\x32\".qcalibrateremote.grpc.InitializedH\x00\x12\x37\n\nparameters\x18\x02 \x01(\x0b\x32!.qcalibrateremote.grpc.ParametersH\x00\x12)\n\x03\x65nd\x18\n \x01(\x0b\x32\x1a.qcalibrateremote.grpc.EndH\x00\x42\t\n\x07message2\xc6\x01\n\nQCalibrate\x12j\n\rAddExperiment\x12+.qcalibrateremote.grpc.AddExperimentRequest\x1a*.qcalibrateremote.grpc.AddExperimentResult\"\x00\x12L\n\x03Run\x12\x1e.qcalibrateremote.grpc.Request\x1a\x1f.qcalibrateremote.grpc.Response\"\x00(\x01\x30\x01\x42*\n\x10\x65u.qruise.qserveB\x0fQCalibrateProtoP\x01\xa2\x02\x02QCb\x06proto3'
)




_ADDEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='AddExperimentRequest',
  full_name='qcalibrateremote.grpc.AddExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qcalibrateremote.grpc.AddExperimentRequest.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='qcalibrateremote.grpc.AddExperimentRequest.type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='qcalibrateremote.grpc.AddExperimentRequest.description', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='qcalibrateremote.grpc.AddExperimentRequest.configuration', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=137,
)


_ADDEXPERIMENTRESULT = _descriptor.Descriptor(
  name='AddExperimentResult',
  full_name='qcalibrateremote.grpc.AddExperimentResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='qcalibrateremote.grpc.AddExperimentResult.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=183,
)


_INITIALIZE = _descriptor.Descriptor(
  name='Initialize',
  full_name='qcalibrateremote.grpc.Initialize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='qcalibrateremote.grpc.Initialize.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='qcalibrateremote.grpc.Initialize.experiment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=240,
)


_INITIALIZED = _descriptor.Descriptor(
  name='Initialized',
  full_name='qcalibrateremote.grpc.Initialized',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='qcalibrateremote.grpc.Initialized.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='qcalibrateremote.grpc.Initialized.run_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typ', full_name='qcalibrateremote.grpc.Initialized.typ', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='qcalibrateremote.grpc.Initialized.module_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='qcalibrateremote.grpc.Initialized.class_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='qcalibrateremote.grpc.Initialized.arguments', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='qcalibrateremote.grpc.Initialized.configuration', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter_metas', full_name='qcalibrateremote.grpc.Initialized.parameter_metas', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulse_metas', full_name='qcalibrateremote.grpc.Initialized.pulse_metas', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=542,
)


_PULSEMETA = _descriptor.Descriptor(
  name='PulseMeta',
  full_name='qcalibrateremote.grpc.PulseMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='qcalibrateremote.grpc.PulseMeta.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='qcalibrateremote.grpc.PulseMeta.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='qcalibrateremote.grpc.PulseMeta.configuration', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=607,
)


_PARAMETERMETA = _descriptor.Descriptor(
  name='ParameterMeta',
  full_name='qcalibrateremote.grpc.ParameterMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='qcalibrateremote.grpc.ParameterMeta.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='qcalibrateremote.grpc.ParameterMeta.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='qcalibrateremote.grpc.ParameterMeta.configuration', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=676,
)


_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='qcalibrateremote.grpc.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qcalibrateremote.grpc.Argument.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64', full_name='qcalibrateremote.grpc.Argument.int64', index=1,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double', full_name='qcalibrateremote.grpc.Argument.double', index=2,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string', full_name='qcalibrateremote.grpc.Argument.string', index=3,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool', full_name='qcalibrateremote.grpc.Argument.bool', index=4,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='qcalibrateremote.grpc.Argument.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=678,
  serialized_end=780,
)


_START = _descriptor.Descriptor(
  name='Start',
  full_name='qcalibrateremote.grpc.Start',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=789,
)


_END = _descriptor.Descriptor(
  name='End',
  full_name='qcalibrateremote.grpc.End',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typ', full_name='qcalibrateremote.grpc.End.typ', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='qcalibrateremote.grpc.End.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=824,
)


_PULSE = _descriptor.Descriptor(
  name='Pulse',
  full_name='qcalibrateremote.grpc.Pulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='times', full_name='qcalibrateremote.grpc.Pulse.times', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='qcalibrateremote.grpc.Pulse.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=872,
)


_PARAMETERS = _descriptor.Descriptor(
  name='Parameters',
  full_name='qcalibrateremote.grpc.Parameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteration', full_name='qcalibrateremote.grpc.Parameters.iteration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='qcalibrateremote.grpc.Parameters.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulses', full_name='qcalibrateremote.grpc.Parameters.pulses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=971,
)


_FOM = _descriptor.Descriptor(
  name='Fom',
  full_name='qcalibrateremote.grpc.Fom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteration', full_name='qcalibrateremote.grpc.Fom.iteration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='figure_of_merit', full_name='qcalibrateremote.grpc.Fom.figure_of_merit', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='qcalibrateremote.grpc.Fom.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1036,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='qcalibrateremote.grpc.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialize', full_name='qcalibrateremote.grpc.Request.initialize', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='qcalibrateremote.grpc.Request.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fom', full_name='qcalibrateremote.grpc.Request.fom', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='qcalibrateremote.grpc.Request.end', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='qcalibrateremote.grpc.Request.message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1039,
  serialized_end=1249,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='qcalibrateremote.grpc.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialized', full_name='qcalibrateremote.grpc.Response.initialized', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='qcalibrateremote.grpc.Response.parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='qcalibrateremote.grpc.Response.end', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='qcalibrateremote.grpc.Response.message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1252,
  serialized_end=1432,
)

_INITIALIZED.fields_by_name['arguments'].message_type = _ARGUMENT
_INITIALIZED.fields_by_name['parameter_metas'].message_type = _PARAMETERMETA
_INITIALIZED.fields_by_name['pulse_metas'].message_type = _PULSEMETA
_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['int64'])
_ARGUMENT.fields_by_name['int64'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['double'])
_ARGUMENT.fields_by_name['double'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['string'])
_ARGUMENT.fields_by_name['string'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['bool'])
_ARGUMENT.fields_by_name['bool'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_PARAMETERS.fields_by_name['pulses'].message_type = _PULSE
_REQUEST.fields_by_name['initialize'].message_type = _INITIALIZE
_REQUEST.fields_by_name['start'].message_type = _START
_REQUEST.fields_by_name['fom'].message_type = _FOM
_REQUEST.fields_by_name['end'].message_type = _END
_REQUEST.oneofs_by_name['message'].fields.append(
  _REQUEST.fields_by_name['initialize'])
_REQUEST.fields_by_name['initialize'].containing_oneof = _REQUEST.oneofs_by_name['message']
_REQUEST.oneofs_by_name['message'].fields.append(
  _REQUEST.fields_by_name['start'])
_REQUEST.fields_by_name['start'].containing_oneof = _REQUEST.oneofs_by_name['message']
_REQUEST.oneofs_by_name['message'].fields.append(
  _REQUEST.fields_by_name['fom'])
_REQUEST.fields_by_name['fom'].containing_oneof = _REQUEST.oneofs_by_name['message']
_REQUEST.oneofs_by_name['message'].fields.append(
  _REQUEST.fields_by_name['end'])
_REQUEST.fields_by_name['end'].containing_oneof = _REQUEST.oneofs_by_name['message']
_RESPONSE.fields_by_name['initialized'].message_type = _INITIALIZED
_RESPONSE.fields_by_name['parameters'].message_type = _PARAMETERS
_RESPONSE.fields_by_name['end'].message_type = _END
_RESPONSE.oneofs_by_name['message'].fields.append(
  _RESPONSE.fields_by_name['initialized'])
_RESPONSE.fields_by_name['initialized'].containing_oneof = _RESPONSE.oneofs_by_name['message']
_RESPONSE.oneofs_by_name['message'].fields.append(
  _RESPONSE.fields_by_name['parameters'])
_RESPONSE.fields_by_name['parameters'].containing_oneof = _RESPONSE.oneofs_by_name['message']
_RESPONSE.oneofs_by_name['message'].fields.append(
  _RESPONSE.fields_by_name['end'])
_RESPONSE.fields_by_name['end'].containing_oneof = _RESPONSE.oneofs_by_name['message']
DESCRIPTOR.message_types_by_name['AddExperimentRequest'] = _ADDEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['AddExperimentResult'] = _ADDEXPERIMENTRESULT
DESCRIPTOR.message_types_by_name['Initialize'] = _INITIALIZE
DESCRIPTOR.message_types_by_name['Initialized'] = _INITIALIZED
DESCRIPTOR.message_types_by_name['PulseMeta'] = _PULSEMETA
DESCRIPTOR.message_types_by_name['ParameterMeta'] = _PARAMETERMETA
DESCRIPTOR.message_types_by_name['Argument'] = _ARGUMENT
DESCRIPTOR.message_types_by_name['Start'] = _START
DESCRIPTOR.message_types_by_name['End'] = _END
DESCRIPTOR.message_types_by_name['Pulse'] = _PULSE
DESCRIPTOR.message_types_by_name['Parameters'] = _PARAMETERS
DESCRIPTOR.message_types_by_name['Fom'] = _FOM
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddExperimentRequest = _reflection.GeneratedProtocolMessageType('AddExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDEXPERIMENTREQUEST,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.AddExperimentRequest)
  })
_sym_db.RegisterMessage(AddExperimentRequest)

AddExperimentResult = _reflection.GeneratedProtocolMessageType('AddExperimentResult', (_message.Message,), {
  'DESCRIPTOR' : _ADDEXPERIMENTRESULT,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.AddExperimentResult)
  })
_sym_db.RegisterMessage(AddExperimentResult)

Initialize = _reflection.GeneratedProtocolMessageType('Initialize', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZE,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Initialize)
  })
_sym_db.RegisterMessage(Initialize)

Initialized = _reflection.GeneratedProtocolMessageType('Initialized', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZED,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Initialized)
  })
_sym_db.RegisterMessage(Initialized)

PulseMeta = _reflection.GeneratedProtocolMessageType('PulseMeta', (_message.Message,), {
  'DESCRIPTOR' : _PULSEMETA,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.PulseMeta)
  })
_sym_db.RegisterMessage(PulseMeta)

ParameterMeta = _reflection.GeneratedProtocolMessageType('ParameterMeta', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERMETA,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.ParameterMeta)
  })
_sym_db.RegisterMessage(ParameterMeta)

Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENT,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Argument)
  })
_sym_db.RegisterMessage(Argument)

Start = _reflection.GeneratedProtocolMessageType('Start', (_message.Message,), {
  'DESCRIPTOR' : _START,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Start)
  })
_sym_db.RegisterMessage(Start)

End = _reflection.GeneratedProtocolMessageType('End', (_message.Message,), {
  'DESCRIPTOR' : _END,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.End)
  })
_sym_db.RegisterMessage(End)

Pulse = _reflection.GeneratedProtocolMessageType('Pulse', (_message.Message,), {
  'DESCRIPTOR' : _PULSE,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Pulse)
  })
_sym_db.RegisterMessage(Pulse)

Parameters = _reflection.GeneratedProtocolMessageType('Parameters', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERS,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Parameters)
  })
_sym_db.RegisterMessage(Parameters)

Fom = _reflection.GeneratedProtocolMessageType('Fom', (_message.Message,), {
  'DESCRIPTOR' : _FOM,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Fom)
  })
_sym_db.RegisterMessage(Fom)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Request)
  })
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'qcalibrate_pb2'
  # @@protoc_insertion_point(class_scope:qcalibrateremote.grpc.Response)
  })
_sym_db.RegisterMessage(Response)


DESCRIPTOR._options = None
_PULSE.fields_by_name['times']._options = None
_PULSE.fields_by_name['values']._options = None
_PARAMETERS.fields_by_name['values']._options = None

_QCALIBRATE = _descriptor.ServiceDescriptor(
  name='QCalibrate',
  full_name='qcalibrateremote.grpc.QCalibrate',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1435,
  serialized_end=1633,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddExperiment',
    full_name='qcalibrateremote.grpc.QCalibrate.AddExperiment',
    index=0,
    containing_service=None,
    input_type=_ADDEXPERIMENTREQUEST,
    output_type=_ADDEXPERIMENTRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Run',
    full_name='qcalibrateremote.grpc.QCalibrate.Run',
    index=1,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QCALIBRATE)

DESCRIPTOR.services_by_name['QCalibrate'] = _QCALIBRATE

# @@protoc_insertion_point(module_scope)
